"""Common elements"""

import pygame
import os
import sys

import serge.engine
import serge.common
import serge.blocks.scores

log = serge.common.getLogger('Game')
from theme import G

version = '0.2'

MUSIC_ON = 0

def startMusic(name):
    """Start music playing"""
    pygame.mixer.music.stop()
    filename, trackname = G(name)
    pygame.mixer.music.load(os.path.join('sound', filename))
    pygame.mixer.music.play(-1) 
    #
    # Set the title of the track
    title = serge.engine.CurrentEngine().getCurrentWorld().findActorByName('music-title')
    title.setText(trackname)
    #
    # Don't play if we are not supposed to. We start and pause so that an unpause will work
    if MUSIC_ON == 1:
        pygame.mixer.music.pause()        

def registerHighScores():
    """Setup a high score table""" 
    global HIGH_SCORES 
    var = 'HOME' if not sys.platform.startswith('win') else 'HOMEPATH'
    score_filename = os.path.join(os.getenv(var), '.magnetospheres.scores')
    if os.path.isfile(score_filename):
        log.info('Loading scores from %s' % score_filename)
        HIGH_SCORES = serge.serialize.Serializable.fromFile(score_filename)
    else:
        log.info('New scores file at %s' % score_filename)
        HIGH_SCORES = resetTable()
    return HIGH_SCORES

def resetTable():
    """Reset the scores table"""   
    global HIGH_SCORES 
    HIGH_SCORES = serge.blocks.scores.HighScoreTable()
    for level in range(50):
        HIGH_SCORES.addCategory('level %d' % level, 
                number=1, sort_columns=[1], directions=['descending'])
    saveScores()
    return HIGH_SCORES

def saveScores():
    """Save the high scores"""
    var = 'HOME' if not sys.platform.startswith('win') else 'HOMEPATH'
    score_filename = os.path.join(os.getenv(var), '.magnetospheres.scores')
    HIGH_SCORES.toFile(score_filename)
        
