"""Shows the current scores"""

import pymunk
import random

import serge.actor
import serge.engine
import serge.blocks.visualblocks

from theme import G


class ScoreBoard(serge.actor.Actor):
    """Shows the current user scores"""
    
    def __init__(self, red, green, blue):
        """Initialise the ScoreBoard"""
        super(ScoreBoard, self).__init__('scoreboard', 'scoreboard')
        self.scores = {'red':0, 'green':0, 'blue':0}
        self.drawer = serge.blocks.visualblocks.Rectangle((0, 20), G('red'))
        self.text = serge.visual.Text('', G('scoreboard-text-colour'), font_size=G('scoreboard-text-size'), justify='center')
        self.setLayerName('ui')
        self.setTargets(red, green, blue)
        self.mouse = serge.engine.CurrentEngine().getMouse()
        self.clock = 0.0
        self.frozen = False
        self.best = None
    
    def setTargets(self, red, green, blue):
        """Set the target scores"""
        self.targets = {'red':red, 'green':green, 'blue':blue}
                
    def addScore(self, colour, amount):
        """Add a score amount"""
        self.scores[colour] = max(0, min(self.scores[colour]+amount, self.targets[colour]))

    def updateActor(self, interval, world):
        """Update the actor"""
        #
        # When the right mouse is being used we gradually use up our score
        if self.mouse.isDown(serge.input.M_RIGHT):
            for colour in ('red', 'green', 'blue'):
                self.scores[colour] = max(0, self.scores[colour]-G('drain-rate-nudge'))   
        if not self.frozen:
            self.clock += interval/1000.0         
            self.frozen = self.targetComplete()
        
    def renderTo(self, renderer, interval):
        """docstring"""
        surface = renderer.getLayer(self.layer).getSurface()
        self.text.setFontSize(G('scoreboard-text-size'))
        self.text.setColour(G('scoreboard-text-colour'))
        self.text.setText('Scores')
        self.text.renderTo(0, surface, (G('scoreboard-text-x'), G('scoreboard-text-y')))
        self.text.setText('Time')
        self.text.renderTo(0, surface, (G('scoreboard-time-text-x'), G('scoreboard-time-text-y')))        
        self.text.colour = G('scoreboard-time-colour')
        self.text.setText('%02d:%02d' % (self.clock//60, self.clock%60))
        self.text.setColour(G('scoreboard-time-colour'))
        self.text.renderTo(0, surface, (G('scoreboard-time-x'), G('scoreboard-time-y')))  
        if self.best:
            self.text.setText('(Best %02d:%02d)' % (self.best//60, self.best%60))
            self.text.setFontSize(G('scoreboard-best-size'))
            self.text.setColour(G('scoreboard-best-colour'))
            self.text.renderTo(0, surface, (G('scoreboard-best-x'), G('scoreboard-best-y')))        
        #
        for colour in ('red', 'green', 'blue'):
            light = int(100*self.scores[colour]/self.targets[colour])
            dark = 100-light
            #
            # Do the light part of the rectangle
            if light:
                self.drawer.colour = G(colour)
                self.drawer.width = light
                self.drawer.renderTo(0, surface, (G('scoreboard-x'), G('scoreboard-%s-y' % colour)))       
            #
            # Now the dark
            if dark:
                self.drawer.colour = G('dark-%s' % colour)
                self.drawer.width = dark
                self.drawer.renderTo(0, surface, (G('scoreboard-x')+light, G('scoreboard-%s-y' % colour)))       

    def targetComplete(self):
        """Return True if we have reached our target"""
        for colour in ('red', 'green', 'blue'):
            if self.scores[colour] < self.targets[colour]:
                return False
        else:
            return True
        
    def setComplete(self):
        """Set the scores to the targets"""
        for colour in ('red', 'green', 'blue'):
            self.scores[colour] = self.targets[colour]

    def isZero(self):
        """Return True if we have no score"""
        return max(self.scores.values()) == 0
                
